@@ -1,11 +1,13 @@
 use super::scalar_;
 use crate::{prelude::*, scalar, Point, Point3, RSXform, Rect, Scalar, Size, Vector};
-use skia_bindings as sb;
-use skia_bindings::SkMatrix;
-use std::ops::{Index, IndexMut, Mul};
-use std::slice;
+use skia_bindings::{self as sb, SkMatrix};
+use std::{
+    ops::{Index, IndexMut, Mul},
+    slice,
+};
 
 pub use skia_bindings::SkApplyPerspectiveClip as ApplyPerspectiveClip;
+variant_name!(ApplyPerspectiveClip::Yes, perspective_clip_naming);
 
 bitflags! {
     // m85: On Windows the SkMatrix_TypeMask is defined as i32,
@@ -25,6 +27,7 @@ impl TypeMask {
 }
 
 pub use skia_bindings::SkMatrix_ScaleToFit as ScaleToFit;
+variant_name!(ScaleToFit::Fill, scale_to_fit_naming);
 
 #[repr(C)]
 #[derive(Copy, Clone, Debug)]
@@ -33,7 +36,7 @@ pub struct Matrix {
     type_mask: u32,
 }
 
-impl NativeTransmutable<SkMatrix> for Matrix {}
+native_transmutable!(SkMatrix, Matrix, matrix_layout);
 
 impl PartialEq for Matrix {
     fn eq(&self, rhs: &Self) -> bool {
@@ -820,24 +823,9 @@ pub const IDENTITY: Matrix = Matrix::new_identity();
 
 #[cfg(test)]
 mod tests {
-    use super::{AffineMember, ApplyPerspectiveClip, Matrix, ScaleToFit, TypeMask};
+    use super::{AffineMember, Matrix, TypeMask};
     use crate::prelude::*;
 
-    #[test]
-    fn test_apply_perspective_clip_naming() {
-        let _ = ApplyPerspectiveClip::Yes;
-    }
-
-    #[test]
-    fn test_matrix_scale_to_fit_naming() {
-        let _ = ScaleToFit::End;
-    }
-
-    #[test]
-    fn test_matrix_layout() {
-        Matrix::test_layout()
-    }
-
     #[test]
     fn test_get_set_trait_compilation() {
         let mut m = Matrix::new_identity();
